==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Output/alsa/translations/alsa_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_TW">
<defaultcodec></defaultcodec>
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>ALSA 插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="50"/>
        <source>About ALSA Output Plugin</source>
        <translation>關於 ALSA 匯出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="51"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Qmmp ALSA 匯出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Device Settings</source>
        <translation>裝置設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio device</source>
        <translation>聲訊裝置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Mixer</source>
        <translation>混頻</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Mixer card:</source>
        <translation>混頻卡：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Mixer device:</source>
        <translation>混頻裝置：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>Advanced Settings</source>
        <translation>進階設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="154"/>
        <source>Soundcard</source>
        <translation>音效卡</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="160"/>
        <source>Buffer time (ms):</source>
        <translation>緩衝時間(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="196"/>
        <source>Period time (ms):</source>
        <translation>周期時間(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="272"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>ALSA Plugin Settings</source>
        <translation>ALSA 插件設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="232"/>
        <source>Use mmap access</source>
        <translation>使用內存對映</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Output/alsa/translations/alsa_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>ALSA 插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>關於 ALSA 匯出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Qmmp ALSA 匯出插件</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="24"/>
        <source>Device Settings</source>
        <translation>裝置設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="36"/>
        <source>Audio device</source>
        <translation>聲訊裝置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Mixer</source>
        <translation>混頻</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Mixer card:</source>
        <translation>混頻卡：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="73"/>
        <source>Mixer device:</source>
        <translation>混頻裝置：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Advanced Settings</source>
        <translation>進階設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="102"/>
        <source>Soundcard</source>
        <translation>音效卡</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="108"/>
        <source>Buffer time (ms):</source>
        <translation>緩衝時間(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="144"/>
        <source>Period time (ms):</source>
        <translation>周期時間(ms)：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>ALSA 插件設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="180"/>
        <source>Use mmap access</source>
        <translation>使用內存對映</translation>
    </message>
</context>
</TS>
